@@ -2,7 +2,7 @@ package Test2::Harness::UI::Controller::Run;
 use strict;
 use warnings;
 
-our $VERSION = '0.000005';
+our $VERSION = '0.000006';
 
 use Data::GUID;
 use List::Util qw/max/;
@@ -46,7 +46,7 @@ sub handle {
 
     my $ct = lc($req->parameters->{'Content-Type'} || $req->parameters->{'content-type'} || 'text/html');
 
-    if ($route->{action} eq 'pin_toggle') {
+    if ($route->{action} && $route->{action} eq 'pin_toggle') {
         $run->update({pinned => $run->pinned ? 0 : 1});
     }
 
